@@ -48,6 +48,9 @@ struct gvm_configuration {
 	gboolean autovideocam;
 	char *autovideocam_command;
 	
+	gboolean autopalmsync;
+	char *autopalmsync_command;
+	
 	char *eject_command;
 };
 
