@@ -34,7 +34,6 @@ enum {
 	AUTOBROWSE,
 	AUTOBURN,
 	AUTOBURN_AUDIO_CD_COMMAND,
-	AUTOBURN_PHOTO_CD_COMMAND,
 	AUTOBURN_DATA_CD_COMMAND,
 	AUTOIPOD,
 	AUTOIPOD_COMMAND,
@@ -44,6 +43,8 @@ enum {
 	AUTOMOUNT_MEDIA,
 	AUTOMOUSE,
 	AUTOMOUSE_COMMAND,
+	AUTOPALMSYNC,
+	AUTOPALMSYNC_COMMAND,
 	AUTOPHOTO,
 	AUTOPHOTO_COMMAND,
 	AUTOPLAY_CDA,
@@ -72,7 +73,6 @@ static struct {
 	{ GCONF_ROOT "autobrowse",                TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoburn",                  TYPE_BOOL,   NULL, FALSE },
 	{ GCONF_ROOT "autoburn_audio_cd_command", TYPE_STRING, NULL, FALSE },
-	{ GCONF_ROOT "autoburn_photo_cd_command", TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoburn_data_cd_command",  TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoipod",                  TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoipod_command",          TYPE_STRING, NULL, FALSE },
@@ -82,6 +82,8 @@ static struct {
 	{ GCONF_ROOT "automount_media",           TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "automouse",                 TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "automouse_command",         TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autopalmsync",              TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autopalmsync_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autophoto",                 TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autophoto_command",         TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoplay_cda",              TYPE_BOOL,   NULL, TRUE  },
@@ -295,6 +297,8 @@ show_props (void)
 	/* FIXME: need better icon */
 	icon = glade_xml_get_widget (xml, "videocam_image");
 	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-mime-video");
+	icon = glade_xml_get_widget (xml, "palm_image");
+	set_icon (GTK_IMAGE (icon), icon_theme, "palm-pilot");
 	
 	gtk_window_set_default_icon_name ("gnome-dev-cdrom");
 	
